@@ -38,8 +38,8 @@ Copyright (C) CERN 2013-2014
 
 AUTHOR = "Massimo Paladin <massimo.paladin@gmail.com>"
 COPYRIGHT = "Copyright (C) CERN 2013-2014"
-VERSION = "1.0"
-DATE = "5 Aug 2014"
+VERSION = "1.1"
+DATE = "1 Oct 2014"
 __author__ = AUTHOR
 __version__ = VERSION
 __date__ = DATE
